==> kvision-server-ktor-koin-js-5.15.0.jar: kvision-kvision-server-ktor-koin-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kvision-kvision-common-remote-js-legacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kvision-kvision-common-remote-js-legacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-ktor-koin-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-server-ktor-koin-js-legacy'.");
    }
    if (typeof this['kvision-kvision-common-remote-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-ktor-koin-js-legacy'. Its dependency 'kvision-kvision-common-remote-js-legacy' was not found. Please, check whether 'kvision-kvision-common-remote-js-legacy' is loaded prior to 'kvision-kvision-server-ktor-koin-js-legacy'.");
    }
    root['kvision-kvision-server-ktor-koin-js-legacy'] = factory(typeof this['kvision-kvision-server-ktor-koin-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-server-ktor-koin-js-legacy'], kotlin, this['kvision-kvision-common-remote-js-legacy']);
  }
}(this, function (_, Kotlin, $module$kvision_kvision_common_remote_js_legacy) {
  'use strict';
  var KVServiceManagerJs = $module$kvision_kvision_common_remote_js_legacy.io.kvision.remote.KVServiceManagerJs;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var KVServiceMgr = $module$kvision_kvision_common_remote_js_legacy.io.kvision.remote.KVServiceMgr;
  KVServiceManager.prototype = Object.create(KVServiceManagerJs.prototype);
  KVServiceManager.prototype.constructor = KVServiceManager;
  function KVServiceManager(serviceClass) {
    KVServiceManagerJs.call(this);
  }
  KVServiceManager.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVServiceManager',
    interfaces: [KVServiceManagerJs, KVServiceMgr]
  };
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$remote = package$kvision.remote || (package$kvision.remote = {});
  package$remote.KVServiceManager = KVServiceManager;
  Kotlin.defineModule('kvision-kvision-server-ktor-koin-js-legacy', _);
  return _;
}));

==> kvision-server-ktor-koin-js-5.15.3.jar: kvision-kvision-server-ktor-koin-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kvision-kvision-common-remote-js-legacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kvision-kvision-common-remote-js-legacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-ktor-koin-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-server-ktor-koin-js-legacy'.");
    }
    if (typeof this['kvision-kvision-common-remote-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-ktor-koin-js-legacy'. Its dependency 'kvision-kvision-common-remote-js-legacy' was not found. Please, check whether 'kvision-kvision-common-remote-js-legacy' is loaded prior to 'kvision-kvision-server-ktor-koin-js-legacy'.");
    }
    root['kvision-kvision-server-ktor-koin-js-legacy'] = factory(typeof this['kvision-kvision-server-ktor-koin-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-server-ktor-koin-js-legacy'], kotlin, this['kvision-kvision-common-remote-js-legacy']);
  }
}(this, function (_, Kotlin, $module$kvision_kvision_common_remote_js_legacy) {
  'use strict';
  var NotImplementedError = Kotlin.kotlin.NotImplementedError;
  var defineInlineFunction = Kotlin.defineInlineFunction;
  var wrapFunction = Kotlin.wrapFunction;
  var KVServiceManagerJs = $module$kvision_kvision_common_remote_js_legacy.io.kvision.remote.KVServiceManagerJs;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var KVServiceMgr = $module$kvision_kvision_common_remote_js_legacy.io.kvision.remote.KVServiceMgr;
  KVServiceManager.prototype = Object.create(KVServiceManagerJs.prototype);
  KVServiceManager.prototype.constructor = KVServiceManager;
  var getServiceManager = defineInlineFunction('kvision-kvision-server-ktor-koin-js-legacy.io.kvision.remote.getServiceManager_30y1fr$', wrapFunction(function () {
    var getKClass = Kotlin.getKClass;
    var NotImplementedError_init = Kotlin.kotlin.NotImplementedError;
    return function (T_0, isT) {
      throw new NotImplementedError_init("KVision didn't generate code for " + getKClass(T_0).simpleName + '. You need to apply KVision Gradle Plugin.');
    };
  }));
  function getAllServiceManagers() {
    throw new NotImplementedError("KVision didn't generate code. You need to apply KVision Gradle Plugin.");
  }
  function getServiceManagers(kclass) {
    throw new NotImplementedError("KVision didn't generate code. You need to apply KVision Gradle Plugin.");
  }
  function KVServiceManager(serviceClass) {
    KVServiceManagerJs.call(this);
  }
  KVServiceManager.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVServiceManager',
    interfaces: [KVServiceManagerJs, KVServiceMgr]
  };
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$remote = package$kvision.remote || (package$kvision.remote = {});
  package$remote.getAllServiceManagers = getAllServiceManagers;
  package$remote.getServiceManagers_gcxcac$ = getServiceManagers;
  package$remote.KVServiceManager = KVServiceManager;
  Kotlin.defineModule('kvision-kvision-server-ktor-koin-js-legacy', _);
  return _;
}));
